from pydantic import BaseModel, EmailStr
from datetime import datetime
from typing import Optional

class DriverBase(BaseModel):
    name: str
    email: EmailStr
    phone: str
    vehicle_type: str
    vehicle_plate: str
    is_available: bool = True
    rating: float = 5.0

class DriverCreate(DriverBase):
    pass

class DriverUpdate(BaseModel):
    name: Optional[str] = None
    email: Optional[EmailStr] = None
    phone: Optional[str] = None
    vehicle_type: Optional[str] = None
    vehicle_plate: Optional[str] = None
    is_available: Optional[bool] = None
    rating: Optional[float] = None

class Driver(DriverBase):
    id: int
    created_at: datetime
    updated_at: Optional[datetime] = None
    
    class Config:
        from_attributes = True