from pydantic import BaseModel
from datetime import datetime
from typing import Optional
from app.models.order import OrderStatus

class OrderBase(BaseModel):
    customer_id: int
    pickup_address: str
    delivery_address: str
    package_description: Optional[str] = None
    weight: Optional[float] = None
    price: float
    notes: Optional[str] = None

class OrderCreate(OrderBase):
    pass

class OrderUpdate(BaseModel):
    driver_id: Optional[int] = None
    pickup_address: Optional[str] = None
    delivery_address: Optional[str] = None
    package_description: Optional[str] = None
    weight: Optional[float] = None
    price: Optional[float] = None
    status: Optional[OrderStatus] = None
    notes: Optional[str] = None

class Order(OrderBase):
    id: int
    driver_id: Optional[int] = None
    status: OrderStatus
    created_at: datetime
    updated_at: Optional[datetime] = None
    
    class Config:
        from_attributes = True